@@ -131,7 +131,6 @@ public Q_SLOTS:
 
     // minin client
     bool GetIsShowDesktop();
-    void SetShowDesktop(bool isShowDesktop);
 
     void TouchToMove(int x, int y);
     void ClearMoveStatus();
@@ -196,7 +195,6 @@ private:
 
     bool m_isMultitaskingActived = false;
     bool m_isPlatformX11 = true;
-    bool m_isShowDesktop = false;
 };
 
 #endif // DEEPINWMFAKER_H
