@@ -49,6 +49,8 @@ Q_LOGGING_CATEGORY(BLUR_CAT, "kwin.blur", QtCriticalMsg);
 
 static const QByteArray s_GtkFrameAtomName = QByteArrayLiteral("_GTK_FRAME_EXTENTS");
 
+#define WATERMARK_CLASS_NAME "deepin-watermark deepin-watermark"
+
 DesktopThumbnailManager::DesktopThumbnailManager(EffectsHandler* h)
     :QWidget(nullptr),
     m_effectWindow(nullptr),
@@ -255,6 +257,7 @@ MultitaskingEffect::MultitaskingEffect()
     m_showAction(new QAction(this)),
 	m_multitaskingModel(new MultitaskingModel)
 {
+#if 0
     QAction* a = m_showAction;
     a->setObjectName(actionName);
     a->setText(i18n("Show Multitasking View"));
@@ -264,11 +267,11 @@ MultitaskingEffect::MultitaskingEffect()
     KGlobalAccel::self()->setShortcut(a, QList<QKeySequence>() << ks);
     shortcut = KGlobalAccel::self()->shortcut(a);
     effects->registerGlobalShortcut(ks, a);
-
+    connect(a, SIGNAL(triggered(bool)), this, SLOT(toggleActive()));
+#endif
     m_gtkFrameExtentsAtom = effects->announceSupportProperty(s_GtkFrameAtomName, this);
     m_targetDesktop = effects->currentDesktop();
 
-    connect(a, SIGNAL(triggered(bool)), this, SLOT(toggleActive()));
 
     connect(KGlobalAccel::self(), &KGlobalAccel::globalShortcutChanged, this, &MultitaskingEffect::globalShortcutChanged);
     connect(effects, &EffectsHandler::windowAdded, this, &MultitaskingEffect::onWindowAdded);
@@ -610,9 +613,11 @@ void MultitaskingEffect::prePaintWindow(EffectWindow *w, WindowPrePaintData &dat
         w->enablePainting(EffectWindow::PAINT_DISABLED_BY_MINIMIZE);   // Display always
     }
     w->enablePainting(EffectWindow::PAINT_DISABLED);
-    if (!(w->isDesktop() || isRelevantWithPresentWindows(w)) || w->isMinimized()) {
-        w->disablePainting(EffectWindow::PAINT_DISABLED);
-        w->disablePainting(EffectWindow::PAINT_DISABLED_BY_MINIMIZE);
+    if (w->windowClass() != WATERMARK_CLASS_NAME) {
+        if (!(w->isDesktop() || isRelevantWithPresentWindows(w)) || w->isMinimized()) {
+            w->disablePainting(EffectWindow::PAINT_DISABLED);
+            w->disablePainting(EffectWindow::PAINT_DISABLED_BY_MINIMIZE);
+        }
     }
 
     effects->prePaintWindow(w, data, time);
@@ -620,6 +625,9 @@ void MultitaskingEffect::prePaintWindow(EffectWindow *w, WindowPrePaintData &dat
 
 void MultitaskingEffect::paintWindow(EffectWindow *w, int mask, QRegion region, WindowPaintData &data)
 {
+    if (w->windowClass() == WATERMARK_CLASS_NAME) {
+        effects->setElevatedWindow(w, true);
+    }
     effects->paintWindow(w, mask, region, data);
 }
 
@@ -1354,6 +1362,12 @@ void MultitaskingEffect::setActive(bool active)
             m_multitaskingModel->setCurrentSelectIndex(-1);
         }
     } else {
+        for (auto w : effects->stackingOrder()) {
+            if (w->windowClass() == WATERMARK_CLASS_NAME) {
+                effects->setElevatedWindow(w, false);
+                break;
+            }
+        }
         if (m_hasKeyboardGrab) {
             effects->ungrabKeyboard();
         }
